@@ -4,96 +4,100 @@ from __future__ import print_function
 from __future__ import absolute_import
 from future.standard_library import install_aliases
 install_aliases()
-
-import os, sys, argparse, json, urllib.request, base64, dateutil.parser
+import os
+import sys
+import argparse
+import json
+import urllib.request
+import base64
+import dateutil.parser
 from prettytable import PrettyTable
-from string import *
-
 
 GITHUB_API = 'https://api.github.com/'
 
 API_TOKEN = os.environ.get('GITHUB_TOKEN')
 
-def main():
-    parser = argparse.ArgumentParser(description='Github within the Command Line')
-    g=parser.add_mutually_exclusive_group()
-    g.add_argument('-n','--username', type=str, 
-            help = "Get repos of the given username")
-    g.add_argument('-u','--url', type=str,
-            help = "Get repos from the user profile's URL")
-    g.add_argument('-r','--recursive',type=str,
-            help = "Get the file structure from the repo link")
-    g.add_argument('-R','--readme',type=str,
-            help = "Get the raw version of the repo readme from repo link")
-    g.add_argument('-re','--releases',type=str,
-            help = "Get the list of releases from repo link")
-    g.add_argument('-dt','--tarball',type=str,
-            help = "Download the tarball of the given repo")
-    g.add_argument('-dz','--zipball',type=str,
-            help = "Download the zipball of the given repo")
-    
 
-    if len(sys.argv)==1:
+def main():
+    parser = argparse.ArgumentParser(description='Github within the \
+                                                  Command Line')
+    g = parser.add_mutually_exclusive_group()
+    g.add_argument('-n', '--username', type=str,
+                   help="Get repos of the given username")
+    g.add_argument('-u', '--url', type=str,
+                   help="Get repos from the user profile's URL")
+    g.add_argument('-r', '--recursive', type=str,
+                   help="Get the file structure from the repo link")
+    g.add_argument('-R', '--readme', type=str,
+                   help="Get the raw version of the repo readme from repo link")
+    g.add_argument('-re', '--releases', type=str,
+                   help="Get the list of releases from repo link")
+    g.add_argument('-dt', '--tarball', type=str,
+                   help="Download the tarball of the given repo")
+    g.add_argument('-dz', '--zipball', type=str,
+                   help="Download the zipball of the given repo")
+
+    if len(sys.argv) == 1:
         parser.print_help()
         return
 
     args = parser.parse_args()
-    
-#URL
+
+# URL
 
     if(args.url):
-        name=args.url
-        n=name.find("github.com")
-        if(n>=0):
-            if(n!=0):
-                n1=name.find("www.github.com")
-                n2=name.find("http://github.com")
-                n3=name.find("https://github.com")
-                if(n1*n2*n3!=0):
+        name = args.url
+        n = name.find("github.com")
+        if(n >= 0):
+            if(n != 0):
+                n1 = name.find("www.github.com")
+                n2 = name.find("http://github.com")
+                n3 = name.find("https://github.com")
+                if(n1*n2*n3 != 0):
                     print('-'*150)
                     print("Enter a valid URL. For help, type 'cli-github -h'")
                     print('-'*150)
                     return
-            name=args.url[n+11:]
+            name = args.url[n+11:]
             if name.endswith('/'):
                 name = name[:-1]
-            url = GITHUB_API + 'users/' +name + '/repos'
+            url = GITHUB_API + 'users/' + name + '/repos'
         else:
             print('-'*150)
             print("Enter a valid URL. For help, type 'cli-github -h'")
             print('-'*150)
             return
 
-#USERNAME
+# USERNAME
 
     if(args.username):
-        name=args.username
-        url = GITHUB_API + 'users/' +name + '/repos'
+        name = args.username
+        url = GITHUB_API + 'users/' + name + '/repos'
 
-#TREE
+# TREE
 
     if(args.recursive):
-        name=args.recursive
-        n=name.find("github.com")
-        if(n>=0):
-            if(n!=0):
-                n1=name.find("www.github.com")
-                n2=name.find("http://github.com")
-                n3=name.find("https://github.com")
-                if(n1*n2*n3!=0):
+        name = args.recursive
+        n = name.find("github.com")
+        if(n >= 0):
+            if(n != 0):
+                n1 = name.find("www.github.com")
+                n2 = name.find("http://github.com")
+                n3 = name.find("https://github.com")
+                if(n1*n2*n3 != 0):
                     print('-'*150)
                     print("Enter a valid URL. For help, type 'cli-github -h'")
                     print('-'*150)
                     return
-            name=args.recursive[n+11:]
+            name = args.recursive[n+11:]
             if name.endswith('/'):
                     name = name[:-1]
-            url = GITHUB_API + 'repos/' +name + '/branches/master'
+            url = GITHUB_API + 'repos/' + name + '/branches/master'
             request = urllib.request.Request(url)
             request.add_header('Authorization', 'token %s' % API_TOKEN)
             try:
                 response = urllib.request.urlopen(request).read().decode('utf-8')
-            except urllib.error.HTTPError as err:
+            except urllib.error.HTTPError:
                 print('-'*150)
                 print("Invalid Credentials. For help, type 'cli-github -h'")
                 print('-'*150)
@@ -103,81 +107,81 @@ def main():
             print("Enter a valid URL. For help, type 'cli-github -h'")
             print('-'*150)
             return
- 
+
         jsondata = json.loads(response)
         sha = jsondata['commit']['commit']['tree']['sha']
-        url=GITHUB_API+'repos/'+name+'/git/trees/'+sha+'?recursive=1'
+        url = GITHUB_API + 'repos/' + name + '/git/trees/' + sha + '?recursive=1'
 
-#README
+# README
 
     if(args.readme):
-        name=args.readme
-        n=name.find("github.com")
-        if(n>=0):
-            if(n!=0):
-                n1=name.find("www.github.com")
-                n2=name.find("http://github.com")
-                n3=name.find("https://github.com")
-                if(n1*n2*n3!=0):
+        name = args.readme
+        n = name.find("github.com")
+        if(n >= 0):
+            if(n != 0):
+                n1 = name.find("www.github.com")
+                n2 = name.find("http://github.com")
+                n3 = name.find("https://github.com")
+                if(n1*n2*n3 != 0):
                     print('-'*150)
                     print("Enter a valid URL. For help, type 'cli-github -h'")
                     print('-'*150)
                     return
-        
-            name=args.readme[n+11:]
+
+            name = args.readme[n+11:]
             if name.endswith('/'):
                     name = name[:-1]
-            url = GITHUB_API + 'repos/' +name + '/readme'
+            url = GITHUB_API + 'repos/' + name + '/readme'
         else:
             print('-'*150)
             print("Enter a valid URL. For help, type 'cli-github -h'")
             print('-'*150)
             return
 
-#RELEASES
-    
+# RELEASES
+
     if(args.releases):
-        name=args.releases
-        n=name.find("github.com")
-        if(n>=0):
-            if(n!=0):
-                n1=name.find("www.github.com")
-                n2=name.find("http://github.com")
-                n3=name.find("https://github.com")
-                if(n1*n2*n3!=0):
+        name = args.releases
+        n = name.find("github.com")
+        if(n >= 0):
+            if(n != 0):
+                n1 = name.find("www.github.com")
+                n2 = name.find("http://github.com")
+                n3 = name.find("https://github.com")
+                if(n1*n2*n3 != 0):
                     print('-'*150)
                     print("Enter a valid URL. For help, type 'cli-github -h'")
                     print('-'*150)
                     return
-            name=args.releases[n+11:]
+            name = args.releases[n+11:]
             if name.endswith('/'):
                     name = name[:-1]
-            url = GITHUB_API + 'repos/' +name + '/releases'
+            url = GITHUB_API + 'repos/' + name + '/releases'
         else:
             print('-'*150)
             print("Enter a valid URL. For help, type 'cli-github -h'")
             print('-'*150)
             return
 
-#TARBALL
+# TARBALL
 
     if(args.tarball):
-        name=args.tarball
-        n=name.find("github.com")
-        if(n>=0):
-            if(n!=0):
-                n1=name.find("www.github.com")
-                n2=name.find("http://github.com")
-                n3=name.find("https://github.com")
-                if(n1*n2*n3!=0):
+        name = args.tarball
+        n = name.find("github.com")
+        if(n >= 0):
+            if(n != 0):
+                n1 = name.find("www.github.com")
+                n2 = name.find("http://github.com")
+                n3 = name.find("https://github.com")
+                if(n1*n2*n3 != 0):
                     print('-'*150)
                     print("Enter a valid URL. For help, type 'cli-github -h'")
                     print('-'*150)
                     return
-            name=args.tarball[n+11:]
+            name = args.tarball[n+11:]
             if name.endswith('/'):
                     name = name[:-1]
-            url = GITHUB_API + 'repos/' +name + '/tarball/master'
+            url = GITHUB_API + 'repos/' + name + '/tarball/master'
 
         else:
             print('-'*150)
@@ -185,25 +189,25 @@ def main():
             print('-'*150)
             return
 
-#ZIPBALL
+# ZIPBALL
 
     if(args.zipball):
-        name=args.zipball
-        n=name.find("github.com")
-        if(n>=0):
-            if(n!=0):
-                n1=name.find("www.github.com")
-                n2=name.find("http://github.com")
-                n3=name.find("https://github.com")
-                if(n1*n2*n3!=0):
+        name = args.zipball
+        n = name.find("github.com")
+        if(n >= 0):
+            if(n != 0):
+                n1 = name.find("www.github.com")
+                n2 = name.find("http://github.com")
+                n3 = name.find("https://github.com")
+                if(n1*n2*n3 != 0):
                     print('-'*150)
                     print("Enter a valid URL. For help, type 'cli-github -h'")
                     print('-'*150)
                     return
-            name=args.zipball[n+11:]
+            name = args.zipball[n+11:]
             if name.endswith('/'):
                     name = name[:-1]
-            url = GITHUB_API + 'repos/' +name + '/zipball/master'
+            url = GITHUB_API + 'repos/' + name + '/zipball/master'
 
         else:
             print('-'*150)
@@ -212,10 +216,10 @@ def main():
             return
 
 
-#GET RESPONSES
+# GET RESPONSES
 
 
-#TARBALL/ZIPBALL
+# TARBALL/ZIPBALL
 
     if(args.tarball or args.zipball):
 
@@ -223,35 +227,35 @@ def main():
         request.add_header('Authorization', 'token %s' % API_TOKEN)
         try:
             response_url = urllib.request.urlopen(request).geturl()
-        except urllib.error.HTTPError as err:
+        except urllib.error.HTTPError:
             print('-'*150)
-            print("Invalid Credentials. For help, type 'clipy-github -h'")
+            print("Invalid Credentials. For help, type 'cli-github -h'")
             print('-'*150)
             return
-        
-        n=name.find('/')
-        name=name[n+1:]
+
+        n = name.find('/')
+        name = name[n+1:]
         if(args.tarball):
-            name=name+'.tar.gz'
+            name = name+'.tar.gz'
         if(args.zipball):
-            name=name+'.zip'
-        print("\nDownloading "+ name + '...\n')
-        urllib.request.urlretrieve(response_url , name)
+            name = name+'.zip'
+        print("\nDownloading " + name + '...\n')
+        urllib.request.urlretrieve(response_url, name)
         print(name + ' has been saved\n')
         return
 
-#OTHER OPTIONS
+# OTHER OPTIONS
 
     request = urllib.request.Request(url)
     request.add_header('Authorization', 'token %s' % API_TOKEN)
     try:
         response = urllib.request.urlopen(request).read().decode('utf-8')
-    except urllib.error.HTTPError as err:
+    except urllib.error.HTTPError:
         print('-'*150)
-        print("Invalid Credentials. For help, type 'clipy-github -h'")
+        print("Invalid Credentials. For help, type 'cli-github -h'")
         print('-'*150)
         return
-        
+
     jsondata = json.loads(response)
 
 # USERNAME and URL
@@ -260,34 +264,34 @@ def main():
         x = PrettyTable([" Repository ", "★ Star"])
         x.align[u" Repository "] = u"l"
         for i in jsondata:
-            x.add_row([i['name'],i['stargazers_count']])
+            x.add_row([i['name'], i['stargazers_count']])
         print(x)
 
-#RECURSIVE TREE
+# RECURSIVE TREE
 
     if(args.recursive):
         x = PrettyTable([" File/Folder ", " Size (Bytes) "])
         x.align[u" File/Folder "] = u"l"
         for i in jsondata['tree']:
-            size='-'
-            path=i['path']+'/'
-            if(i['type']=='blob'):
-                size=i['size']
-                path=path[:-1]
-            x.add_row([path,size])
+            size = '-'
+            path = i['path']+'/'
+            if(i['type'] == 'blob'):
+                size = i['size']
+                path = path[:-1]
+            x.add_row([path, size])
         print(x)
-            
 
-#README
+
+# README
 
     if(args.readme):
-        print(base64.b64decode(jsondata['content']).decode('utf-8'));
+        print(base64.b64decode(jsondata['content']).decode('utf-8'))
 
-#RELEASES
+# RELEASES
 
     if(args.releases):
-        x = PrettyTable([" Release name "," Release Date "," Release Time "])
-        
+        x = PrettyTable([" Release name ", " Release Date ", " Release Time "])
+
         for i in jsondata:
             ti = dateutil.parser.parse(i['published_at'])
             ti = str(ti)
@@ -295,6 +299,5 @@ def main():
             time = ti[11:]
             time = time[:5]
             time = time + ' UTC'
-            x.add_row([i['tag_name'],date,time])
+            x.add_row([i['tag_name'], date, time])
         print(x)
-
